import {
  Box,
  CardActions,
  CardContent,
  IconButton,
  Stack,
  Switch,
  Typography,
} from "@mui/material";
import RightIcon from "@mui/icons-material/ChevronRight";
import DeleteIcon from "@mui/icons-material/Delete";
import { BaseCard, preventPropagation } from "./BaseCard";

interface ProjectCardProps {
  name: string;
  activated: boolean;
  virtuoso_url: string;
  canEdit?: boolean;
  onOpen?: () => void;
  onToggle?: () => void;
  onDelete?: () => void;
}

export function ProjectCard({
  name,
  activated,
  virtuoso_url,
  canEdit = true,
  onOpen,
  onToggle,
  onDelete,
}: ProjectCardProps) {
  return (
    <BaseCard onClick={onOpen}>
      <Stack flex={1} height={"100%"}>
        <Box flex={1}>
          <CardContent>
            <Stack direction={"row"}>
              <Typography
                variant="h5"
                component={"p"}
                fontWeight={"bold"}
                flex={1}
              >
                {name}
              </Typography>
              {canEdit ? (
                <Box>
                  <IconButton
                    onClick={(e) => {
                      preventPropagation(e);
                      if (onDelete) {
                        onDelete();
                      }
                    }}
                    onMouseDown={preventPropagation}
                  >
                    <DeleteIcon />
                  </IconButton>
                </Box>
              ) : null}
            </Stack>
            <Typography variant="body2">{virtuoso_url}</Typography>
          </CardContent>
        </Box>
        <CardActions>
          <Box flex={1}>
            {canEdit ? (
              <Switch
                checked={activated}
                onClick={(e) => {
                  preventPropagation(e);
                  if (onToggle) {
                    onToggle();
                  }
                }}
                onMouseDown={preventPropagation}
              />
            ) : null}
          </Box>
          <IconButton>
            <RightIcon />
          </IconButton>
        </CardActions>
      </Stack>
    </BaseCard>
  );
}
