import { useApiGetImportProcesses } from "@/api/cubicweb";
import { ImportProcess } from "@/types";
import { useState, useEffect, useMemo } from "react";
import { useHandleAuthErrors } from "./useHandleAuthErrors";

export function useGetImportProcesses(props: {
  dataServiceEid?: number;
  recipeEid?: number;
  projectEid?: number;
}) {
  const [loading, setLoading] = useState(true);
  const [data, setData] = useState<ImportProcess[] | undefined>();
  const [error, setError] = useState<string | undefined>();
  const handleAuthErrors = useHandleAuthErrors();
  const getImportProcesses = useApiGetImportProcesses();

  const refresh = useMemo(() => {
    return () => {
      setLoading(true);
      setError(undefined);
      getImportProcesses(props)
        .then((result) => {
          setLoading(false);
          setData(result);
        })
        .catch(handleAuthErrors)
        .catch(() => {
          setError(`Une erreur inconnue est survenue`);
        });
    };
  }, [props, handleAuthErrors]);

  useEffect(() => {
    refresh();
  }, [refresh]);
  return { loading, data, error, refresh };
}
