import { UnknownEidError, useApiGetProject } from "@/api/cubicweb";
import { Project } from "@/types";
import { useState, useEffect, useMemo } from "react";
import { useHandleAuthErrors } from "./useHandleAuthErrors";

export function useGetProject(eid: number) {
  const [loading, setLoading] = useState(true);
  const [data, setData] = useState<Project | undefined>();
  const [error, setError] = useState<string | undefined>();
  const handleAuthErrors = useHandleAuthErrors();
  const getProject = useApiGetProject();

  const refresh = useMemo(() => {
    return () => {
      setLoading(true);
      setError(undefined);
      if (!isNaN(eid)) {
        getProject(eid)
          .then((result) => {
            setLoading(false);
            setData(result);
          })
          .catch(handleAuthErrors)
          .catch((e) => {
            if (e instanceof UnknownEidError) {
              setError(`Impossible de trouver le projet '${eid}'`);
            } else {
              setError(`Une erreur inconnue est survenue`);
            }
          });
      }
    };
  }, [eid, handleAuthErrors]);

  useEffect(() => {
    refresh();
  }, [refresh]);
  return { loading, data, error, refresh };
}
